==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/IAMBundleEntitlement.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IAMBundleEntitlement
 */
@JsonPropertyOrder({ IAMBundleEntitlement.JSON_PROPERTY_RESOURCE_SETS, IAMBundleEntitlement.JSON_PROPERTY_ROLE,
        IAMBundleEntitlement.JSON_PROPERTY_TARGETS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class IAMBundleEntitlement implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESOURCE_SETS = "resourceSets";
    private List<String> resourceSets = null;

    public static final String JSON_PROPERTY_ROLE = "role";
    private String role;

    public static final String JSON_PROPERTY_TARGETS = "targets";
    private List<String> targets = null;

    public IAMBundleEntitlement() {
    }

    public IAMBundleEntitlement resourceSets(List<String> resourceSets) {

        this.resourceSets = resourceSets;
        return this;
    }

    public IAMBundleEntitlement addresourceSetsItem(String resourceSetsItem) {
        if (this.resourceSets == null) {
            this.resourceSets = new ArrayList<>();
        }
        this.resourceSets.add(resourceSetsItem);
        return this;
    }

    /**
     * Get resourceSets
     *
     * @return resourceSets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getResourceSets() {
        return resourceSets;
    }

    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setResourceSets(List<String> resourceSets) {
        this.resourceSets = resourceSets;
    }

    public IAMBundleEntitlement role(String role) {

        this.role = role;
        return this;
    }

    /**
     * Get role
     *
     * @return role
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRole() {
        return role;
    }

    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRole(String role) {
        this.role = role;
    }

    public IAMBundleEntitlement targets(List<String> targets) {

        this.targets = targets;
        return this;
    }

    public IAMBundleEntitlement addtargetsItem(String targetsItem) {
        if (this.targets == null) {
            this.targets = new ArrayList<>();
        }
        this.targets.add(targetsItem);
        return this;
    }

    /**
     * Get targets
     *
     * @return targets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getTargets() {
        return targets;
    }

    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTargets(List<String> targets) {
        this.targets = targets;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IAMBundleEntitlement iaMBundleEntitlement = (IAMBundleEntitlement) o;
        return Objects.equals(this.resourceSets, iaMBundleEntitlement.resourceSets)
                && Objects.equals(this.role, iaMBundleEntitlement.role)
                && Objects.equals(this.targets, iaMBundleEntitlement.targets);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resourceSets, role, targets);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IAMBundleEntitlement {\n");
        sb.append("    resourceSets: ").append(toIndentedString(resourceSets)).append("\n");
        sb.append("    role: ").append(toIndentedString(role)).append("\n");
        sb.append("    targets: ").append(toIndentedString(targets)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/IAMBundleEntitlement.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IAMBundleEntitlement
 */
@JsonPropertyOrder({ IAMBundleEntitlement.JSON_PROPERTY_RESOURCE_SETS, IAMBundleEntitlement.JSON_PROPERTY_ROLE,
        IAMBundleEntitlement.JSON_PROPERTY_TARGETS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class IAMBundleEntitlement implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESOURCE_SETS = "resourceSets";
    private List<String> resourceSets = null;

    public static final String JSON_PROPERTY_ROLE = "role";
    private String role;

    public static final String JSON_PROPERTY_TARGETS = "targets";
    private List<String> targets = null;

    public IAMBundleEntitlement() {
    }

    public IAMBundleEntitlement resourceSets(List<String> resourceSets) {

        this.resourceSets = resourceSets;
        return this;
    }

    public IAMBundleEntitlement addresourceSetsItem(String resourceSetsItem) {
        if (this.resourceSets == null) {
            this.resourceSets = new ArrayList<>();
        }
        this.resourceSets.add(resourceSetsItem);
        return this;
    }

    /**
     * Get resourceSets
     *
     * @return resourceSets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getResourceSets() {
        return resourceSets;
    }

    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setResourceSets(List<String> resourceSets) {
        this.resourceSets = resourceSets;
    }

    public IAMBundleEntitlement role(String role) {

        this.role = role;
        return this;
    }

    /**
     * Get role
     *
     * @return role
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getRole() {
        return role;
    }

    @JsonProperty(JSON_PROPERTY_ROLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRole(String role) {
        this.role = role;
    }

    public IAMBundleEntitlement targets(List<String> targets) {

        this.targets = targets;
        return this;
    }

    public IAMBundleEntitlement addtargetsItem(String targetsItem) {
        if (this.targets == null) {
            this.targets = new ArrayList<>();
        }
        this.targets.add(targetsItem);
        return this;
    }

    /**
     * Get targets
     *
     * @return targets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getTargets() {
        return targets;
    }

    @JsonProperty(JSON_PROPERTY_TARGETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTargets(List<String> targets) {
        this.targets = targets;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IAMBundleEntitlement iaMBundleEntitlement = (IAMBundleEntitlement) o;
        return Objects.equals(this.resourceSets, iaMBundleEntitlement.resourceSets)
                && Objects.equals(this.role, iaMBundleEntitlement.role)
                && Objects.equals(this.targets, iaMBundleEntitlement.targets);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resourceSets, role, targets);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IAMBundleEntitlement {\n");
        sb.append("    resourceSets: ").append(toIndentedString(resourceSets)).append("\n");
        sb.append("    role: ").append(toIndentedString(role)).append("\n");
        sb.append("    targets: ").append(toIndentedString(targets)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
